from api.application.abstractions import UnitOfWork
from api.application.contracts.auth.auth_request import UserCreateRequest
from api.application.protocols.password_hasher import PasswordHasher
from api.domain.user.model import User
from api.domain.user.repository import UserRepository


class CreateUser:
    def __init__(
        self,
        uow: UnitOfWork,
        user_repository: UserRepository,
        password_hasher: PasswordHasher,
    ) -> None:
        self.uow = uow
        self.user_repository = user_repository
        self.hasher = password_hasher

    async def execute(self, request: UserCreateRequest) -> None:
        user = User.create(
            name=request.name,
            email=request.email,
            hashed_password=self.hasher.hash_password(request.password),
        )
        await self.user_repository.create_user(user=user)
        await self.uow.commit()
